@@ -8,6 +8,30 @@ from composable import pipeable
 from functools import reduce
 from toolz import identity, last
 
+__all__ = ("fix_names",
+           "extract",
+           "to_datetime",
+           "recode",
+           "set_index",
+           "row_index_slice",
+           "maybe_tile",
+           "maybe_eval",
+           "any_intention",
+           "tiled_where",
+           "cond_eval",
+           "ifelse",
+           "maybe_combine",
+           "combine_all",
+           "arg_eval_and_combine",
+           "coalesce",
+           "ifelse_and_coalesce",
+           "case_when",
+           "col_zip",
+           "union_all",
+
+          )
+
+
 STARTS_WITH_DIGITS_REGEX = re.compile(r'\d+')
 PUNC_REGEX = re.compile('[{0}]'.format(re.escape(punctuation.replace('_', ''))))
 WS_REGEX = re.compile('[{0}]'.format(re.escape(whitespace)))
